Documentation
¶
Index ¶
Constants ¶
const Type string = "nuget"
Variables ¶
var Manifests = []string{".deps.json"}
Functions ¶
Types ¶
type DotnetDeps ¶
type DotnetDeps struct {
Libraries map[string]DotnetLibrary `json:"libraries"`
}
DotnetDeps - .NET Dependencies
type DotnetLibrary ¶
type DotnetLibrary struct {
Type string `json:"type"`
Path string `json:"path"`
Sha512 string `json:"sha512"`
HashPath string `json:"hashPath"`
}
DotnetLibrary - .NET libraries
type ItemGroup ¶ added in v1.15.0
type ItemGroup struct {
PackageReferences []PackageReference `xml:"PackageReference"`
References []Reference `xml:"Reference"`
}
ItemGroup represents a group of items in the .csproj file
type PackageReference ¶ added in v1.15.0
type PackageReference struct {
Include string `xml:"Include,attr"`
Version string `xml:"Version,attr"`
PrivateAssets string `xml:"PrivateAssets,attr,omitempty"`
IncludeAssets string `xml:"IncludeAssets,attr,omitempty"`
}
PackageReference represents a package reference in the .csproj file
type ProjectFile ¶ added in v1.15.0
type ProjectFile struct {
XMLName xml.Name `xml:"Project"`
PropertyGroup PropertyGroup `xml:"PropertyGroup"`
ItemGroup ItemGroup `xml:"ItemGroup"`
}
ProjectFile represents the structure of a .csproj and .vdproj file.
type PropertyGroup ¶ added in v1.15.0
type PropertyGroup struct {
TargetFramework string `xml:"TargetFramework"`
GenerateDocumentationFile bool `xml:"GenerateDocumentationFile"`
PackageId string `xml:"PackageId"`
PackageVersion string `xml:"PackageVersion"`
Version string `xml:"Version"`
Authors string `xml:"Authors"`
Description string `xml:"Description"`
PackageRequireLicenseAcceptance bool `xml:"PackageRequireLicenseAcceptance"`
PackageReleaseNotes string `xml:"PackageReleaseNotes"`
Copyright string `xml:"Copyright"`
PackageTags string `xml:"PackageTags"`
IsPackable bool `xml:"IsPackable"`
GeneratePackageOnBuild bool `xml:"GeneratePackageOnBuild"`
ProjectUrl string `xml:"ProjectUrl"`
RepositoryUrl string `xml:"RepositoryUrl"`
PackageIcon string `xml:"PackageIcon"`
PackageLicenseExpression string `xml:"PackageLicenseExpression"`
}
PropertyGroup represents a group of properties in the .csproj file
type Reference ¶ added in v1.15.0
type Reference struct {
Include string `xml:"Include,attr"`
Version string `xml:"Version,attr"`
Culture string `xml:"Culture,attr"`
PublicKeyToken string `xml:"PublicKeyToken,attr"`
ProcessorArchitecture string `xml:"processorArchitecture,attr"`
HintPath string `xml:"HintPath,omitempty"`
}
Reference represents a reference in the .csproj file
Click to show internal directories.
Click to hide internal directories.